"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@anycli/command");
const engine_1 = require("./engine");
class Command extends command_1.default {
    constructor() {
        super(...arguments);
        this.engine = new engine_1.default();
    }
    async run() {
        await this.engine.load(this.config);
        let id = this.argv[0];
        if (!id)
            id = 'help';
        await this.engine.runHook('init', { id });
        const cachedCommand = this.engine.findCommand(id);
        if (!cachedCommand)
            return this.commandNotFound(id);
        this.debug('found command', cachedCommand.id);
        const command = await cachedCommand.load();
        this.debug('loaded command', command.id);
        await command.run(this.argv.slice(1), { config: this.config });
    }
    async commandNotFound(id) {
        await this.engine.runHook('command_not_found', { id });
        throw new Error(`command not found: ${id}`);
    }
}
exports.default = Command;
